class GlobalizeTranslation < ActiveRecord::Base
  has_many :globalize_translation_suggestions

  # based on https://github.com/svenfuchs/i18n-active_record/blob/master/lib/i18n/backend/active_record/translation.rb

  scope :ordered, :order => :key

  def self.lookup(keys)
    column_name = connection.quote_column_name('key')
    keys = Array(keys).map! { |key| key.to_s }
    namespace = "#{keys.last}#{I18n::Backend::Flatten::FLATTEN_SEPARATOR}%"
    scoped(:conditions => ["#{column_name} IN (?) OR #{column_name} LIKE ?", keys, namespace])
  end

  def self.available_locales
    find(:all, :select => 'DISTINCT locale').map { |t| t.locale.to_sym }
  end

  def last_key
    key.split(".").last
  end

  # based on doc/pluralization_analysis which was written while analysing
  #   http://unicode.org/repos/cldr-tmp/trunk/diff/supplemental/language_plural_rules.html
  #
  # key - one of 'zero', 'one', 'two', 'few', 'many', 'other'
  def self.is_interpolation_mandatory?(language_code, key)
    rule = I18n.t(:'i18n.plural.rule', :locale => language_code.to_sym, :resolve => false)
    key = key.to_sym
    case key
    when :zero
      return false
    when :one
      return  rule.call(0) == :one || rule.call(21) == :one
    when :two
      return rule.call(102) == :two
    when :few
      return rule.call(4) == :few
    when :many
      return rule.call(6) != :many || rule.call(11) == :many
    when :other
      return true
    else
      raise "unexpected key: #{key}"
    end
  end

end