class GlobalizeTranslationSuggestion < ActiveRecord::Base
  belongs_to :globalize_translation

  validates :value, :presence => true
  validate :interpolations_required?

  after_update :update_suggestion, :if => :votes_changed?

  def interpolations_required?
    original_text = self.globalize_translation.value

    interpolations = original_text.scan(/%?\{.+?\}/)
    unless interpolations.empty?
      translations_interpolation = extract_interpolations(translation)

      if interpolations.sort != translations_interpolation.sort
        errors.add :interpolations, "Translation should include all interpolation elements: #{interpolations.join(", ")}"
      end
    end
  end

  private
  # Updates the original phrase with the suggestion gave by users when the number of votes is met.
  def update_suggestion
    if (self.votes + 1) > ExvoGlobalize.feedback_votes_count
      self.globalize_translation.update_attributes(:value => self.value)
    end
  end
end