# encoding: utf-8
require 'active_support/core_ext/hash/indifferent_access'

module ExvoGlobalize
  module Plurals
    # https://github.com/svenfuchs/i18n/blob/master/test/test_data/locales/plurals.rb

    PLURAL_RULES = HashWithIndifferentAccess.new({
      :af => { # africaans
        :one => 1,
        :other => 2
      },

      :ar => { # arabic
        :zero => 0,
        :one => 1,
        :two => 2,
        :few => 3,
        :many => 11,
        :other => 100
      },

      :az => { # Azerbaijani
        :other => 3
      },

      :be => { # Belarusian
        :one => 1,
        :few => 2,
        :many => 7,
        :other => 10.2
      },

      :bg => { # Bulgarian
        :one => 1,
        :other => 5
      },

      :bn => { # Bengali
        :one => 1,
        :other => 5
      },

      :ca => { # Catalan
        :one => 1,
        :other => 5
      },

      :cs => { # Czech
        :one => 1,
        :few => 2,
        :other => 5
      },

      :cy => { # Welsch # 1 tree.
        :one => 1,
        :two => 2,
        :many => 5,
        :other => 15
      },

      :da => {
        :one => 1,
        :other => 2
      },

      :de => {
        :one => 1,
        :other => 2
      },

      :el => { # Greek
        :one => 1,
        :other => 2
      },

      :en => { #English
        :one => 1,
        :other => 2
      },

      :es => { #Spanish
        :one => 1,
        :other => 2
      },

      :et => { # Estonian
        :one => 1,
        :other => 2
      },

      :eu => { # Basque
        :one => 1,
        :other => 2
      },

      :fa => { # Persian
        :other => 2
      },

      :fi => { # Finnish
        :one => 1,
        :other => 2
      },

      :fil => { # Filipino
        :one => 1,
        :other => 2
      },

      :fr => {
        :one => 1,
        :other => 2
      },

      :ga => { # Irish
        :one => 1,
        :two => 2,
        :other => 5
      },

      :gl => { # Galician
        :one => 1,
        :other => 2
      },

      :gu => { # Gujarati
        :one => 1,
        :other => 2
      },

      :he => { # Hebrew
        :one => 1,
        :other => 2
      },

      :hi => { # Hindi
        :one => 1,
        :other => 2
      },

      :hr => { # Croatian
        :one => 1,
        :few => 2,
        :many => 5,
        :other => 10
      },

      :hu => { # Hungarian
        :other => 2
      },

      :id => { # Indonesian
        :other => 2
      },

      :is => { # Icelandic
        :one => 1,
        :other => 2
      },

      :it => { # Italian
        :one => 1,
        :other => 2
      },

      :ja => { # Japanese
        :other => 2
      },

      :ka => { # Georgian
        :other => 2
      },

      :kn => { # Kannada
        :other => 2
      },

      :ko => { # Korean
        :other => 2
      },

      :lt => { # Lithuanian
        :one => 1,
        :few => 3,
        :other => 22
      },

      :lv => { # Latvian
        :zero => 0,
        :one => 1,
        :other => 3
      },

      :mk => { # Macedonian
        :one => 1,
        :other => 10
      },

      :ms => { # Malay
        :other => 2
      },

      :nl => { # Dutch; Flemish
        :one => 1,
        :other => 2
      },

      :no => { # Norwegian
        :one => 1,
        :other => 2
      },

      :pl => {
        :one => 1,
        :few => 2,
        :other => 5
      },

      :pt => { # Portuguese
        :one => 1,
        :other => 2
      },

      :"pt-PT" => { # Portuguese-Portugal
        :one => 1,
        :other => 2
      },

      :ro => { # Romanian; Moldavian; Moldovan
        :one => 1,
        :few => 2,
        :other => 5
      },

      :ru => {
        :one => 1,
        :few => 2,
        :many => 5,
        :other => 10.5
      },

      :sk => { # Slovak
        :one => 1,
        :few => 2,
        :other => 5
      },

      :sl => { # Slovenian
        :one => 1,
        :two => 2,
        :many => 5,
        :other => 20
      },

      :sq => { # Albanian
        :one => 1,
        :other => 2
      },

      :sr => { # Serbian
        :one => 1,
        :few => 2,
        :many => 10,
        :other => 1.2
      },

      :sv => { # Swedish
        :one => 1,
        :other => 2
      },

      :sw => { # Swahili ; 1 tree
        :one => 1,
        :other => 2
      },

      :ta => { # Tamil
        :one => 1,
        :other => 2
      },

      :te => { # Telugu
        :one => 1,
        :other => 2
      },

      :th => { # Thai
        :other => 2
      },

      :tr => { # Turkish
        :other => 2
      },

      :uk => {
        :one => 1,
        :few => 2,
        :many => 5,
        :other => 10
      },

      :ur => { # Urdu
        :one => 1,
        :other => 2
      },

      :vi => { # Vietnamese
        :other => 2
      },

      :zh => { # Chinese
        :other => 2
      }
    })

    HINTS = HashWithIndifferentAccess.new({
      :af => { # africaans
        :one => "appel",
        :other => "appels"
      },

  #    :am => { # Amharic
  #      :one => "",
  #      :other => ""
  #    }, 

      :ar => { # arabic
        :zero => "لا التفاح",
        :one => "تفاحة",
        :two => "التفاح",
        :few => "التفاح",
        :many => "التفاح",
        :other => "التفاح"
      },

      :az => { # Azerbaijani
        :other => "alma"
      },

      :be => { # Belarusian
        :one => "яблык",
        :few => "яблыка",
        :many => "яблыкаў",
        :other => "яблыкаў"
      },

      :bg => { # Bulgarian
        :one => "ябълка",
        :other => "ябълки"
      },

  #    :bh => { # Bihari languages
  #      :one => "",
  #      :other => ""
  #    },

      :bn => { # Bengali
        :one => "আপেল",
        :other => "আপেল"
      },

  #    :bo => { # Tibetan
  #      :other => ""
  #    },
  #
  #    :bs => { #  Bosnian
  #      :one => "",
  #      :few => "",
  #      :many => "",
  #      :other => ""
  #    },

      :ca => { # Catalan
        :one => "poma",
        :other => "pomes"
      },

      :cs => { # Czech
        :one => "jablko",
        :few => "jablka",
        :other => "jablek"
      },

      :cy => { # Welsch # tree.
        :one => "goeden",
        :two => "goeden",
        :many => "coed",
        :other => "o goed"
      },

      :da => {
        :one => "æble",
        :other => "æbler"
      },

      :de => {
        :one => "Apfel",
        :other => "Äpfel"
      },

  #    :dz => { # Dzongkha
  #      :other => ""
  #    },

      :el => { # Greek
        :one => "μήλο",
        :other => "μήλα"
      },

      :en => { #English
        :one => "apple",
        :other => "apples"
      },

  #    :eo => { #Esperanto
  #      :one => "",
  #      :other => ""
  #    },

      :es => { #Spanish
        :one => "manzana",
        :other => "manzanas"
      },

      :et => { # Estonian
        :one => "õun",
        :other => "õuna"
      },

      :eu => { # Basque
        :one => "sagar",
        :other => "sagarrak"
      },

      :fa => { # Persian
        :other => "سیب"
      },

      :fi => { # Finnish
        :one => "omena",
        :other => "omenaa"
      },

      :fil => { # Filipino
        :one => "mansanas",
        :other => "mansanas"
      },

  #    :fo => { # Faroese
  #      :one => "",
  #      :other => ""
  #    },

      :fr => {
        :one => "pomme",
        :other => "pommes"
      },

  #    :fur => { # Friulian
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :fy => { # Western Frisian
  #      :one => "",
  #      :other => ""
  #    },

      :ga => { # Irish
        :one => "úll",
        :two => "úlla",
        :other => "úll"
      },

      :gl => { # Galician
        :one => "mazá",
        :other => "mazás"
      },

      :gu => { # Gujarati
        :one => "સફરજન",
        :other => "સફરજન"
      },

  #    :guw => { # not found..
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :ha => { # Hausa
  #      :one => "",
  #      :other => ""
  #    },

      :he => { # Hebrew
        :one => "תפוח",
        :other => "תפוחים"
      },

      :hi => { # Hindi
        :one => "सेब",
        :other => "सेब"
      },

      :hr => { # Croatian
        :one => "jabuka",
        :few => "jabuke",
        :many => "jabuka",
        :other => "jabuke"
      },

      :hu => { # Hungarian
        :other => "alma"
      },

      :id => { # Indonesian
        :other => "apel"
      },

      :is => { # Icelandic
        :one => "epli",
        :other => "epli"
      },

      :it => { # Italian
        :one => "mela",
        :other => "mele"
      },

  #    :iw => { # couldn't find
  #      :one => "",
  #      :other => ""
  #    },

      :ja => { # Japanese
        :other => "りんご"
      },

  #    :jv => { # Javanese
  #      :other => ""
  #    },

      :ka => { # Georgian
        :other => "ვაშლი"
      },

  #    :km => { # Central Khmer
  #      :other => ""
  #    },

      :kn => { # Kannada
        :other => "ಸೇಬು"
      },

      :ko => { # Korean
        :other => "사과"
      },

  #    :ku => { # Kurdish
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :lb => { # Luxembourgish; Letzeburgesch
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :ln => { # Lingala
  #      :one => "",
  #      :other => ""
  #    },

      :lt => { # Lithuanian
        :one => "obuolys",
        :few => "obuoliai",
        :other => "obuolių"
      },

      :lv => { # Latvian
        :zero => "nav āboli",
        :one => "ābols",
        :other => "ābolu"
      },

  #    :mg => { # Malagasy
  #      :one => "",
  #      :other => ""
  #    },

      :mk => { # Macedonian
        :one => "јаболко",
        :other => "јаболки"
      },

  #    :ml => { # Malayalam
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :mn => { # Mongolian
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :mo => { # Not found
  #      :one => "",
  #      :few => "",
  #      :other => ""
  #    },
  #
  #    :mr => { # Marathi
  #      :one => "",
  #      :other => ""
  #    },

      :ms => { # Malay
        :other => "epal"
      },

  #    :mt => { # Maltese
  #      :one => "",
  #      :few => "",
  #      :many => "",
  #      :other => ""
  #    },
  #
  #    :my => { # Burmese
  #      :other => ""
  #    },
  #
  #    :nah => { # Nahuatl languages
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :nb => { # Bokmål, Norwegian; Norwegian Bokmål
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :ne => { # Nepali
  #      :one => "",
  #      :other => ""
  #    },

      :nl => { # Dutch; Flemish
        :one => "appel",
        :other => "appels"
      },

  #    :nn => { # Norwegian Nynorsk; Nynorsk, Norwegian
  #      :one => "",
  #      :other => ""
  #    },

      :no => { # Norwegian
        :one => "eple",
        :other => "epler"
      },

  #    :nso => { # Pedi; Sepedi; Northern Sotho
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :om => { # Oromo
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :or => { # Oriya
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :pa => {
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :pap => {
  #      :one => "",
  #      :other => ""
  #    },

      :pl => {
        :one => "jabłko",
        :few => "jabłka",
        :other => "jabłek"
      },

      :ps => { # Pushto; Pashto
        :one => "",
        :other => ""
      },

      :pt => { # Portuguese
        :one => "maça",
        :other => "maças"
      },

      :"pt-PT" => { # Portuguese-Portugal
        :one => "maça",
        :other => "maças"
      },

      :ro => { # Romanian; Moldavian; Moldovan
        :one => "mar",
        :few => "mere",
        :other => "mere"
      },

      :ru => {
        :one => "яблоко",
        :few => "яблока",
        :many => "яблок",
        :other => "яблок"
      },

  #    :se => { # Northern Sami
  #      :one => "",
  #      :two => "",
  #      :other => ""
  #    },
  #
  #    :sh => { # Not found
  #      :one => "",
  #      :few => "",
  #      :many => "",
  #      :other => ""
  #    },

      :sk => { # Slovak
        :one => "jablko",
        :few => "jablká",
        :other => "jabĺk"
      },

      :sl => { # Slovenian
        :one => "jabolko",
        :two => "jabolki",
        :many => "jabolk",
        :other => "apples"
      },

  #    :sma => { # Southern Sami
  #      :one => "",
  #      :two => "",
  #      :other => ""
  #    },
  #
  #    :smi => { # Sami languages
  #      :one => "",
  #      :two => "",
  #      :other => ""
  #    },
  #
  #    :smj => { # Lule Sami
  #      :one => "",
  #      :two => "",
  #      :other => ""
  #    },
  #
  #    :smn => { # Inari Sami
  #      :one => "",
  #      :two => "",
  #      :other => ""
  #    },
  #
  #    :sms => { # Skolt Sami
  #      :one => "",
  #      :two => "",
  #      :other => ""
  #    },
  #
  #    :so => { # Somali
  #      :one => "",
  #      :other => ""
  #    },

      :sq => { # Albanian
        :one => "molle",
        :other => "mollë"
      },


      :sr => { # Serbian
        :one => "јабука",
        :few => "јабуке",
        :many => "јабуке",
        :other => "apples"
      },

      :sv => { # Swedish
        :one => "äpple",
        :other => "äpplen"
      },

      :sw => { # Swahili ; tree
        :one => "mti",
        :other => "miti"
      },

      :ta => { # Tamil
        :one => "ஆப்பிள்",
        :other => "ஆப்பிள்கள்"
      },

      :te => { # Telugu
        :one => "ఆపిల్",
        :other => "ఆపిల్ల"
      },

      :th => { # Thai
        :other => "แอปเปิ้ล"
      },

  #    :ti => { # Tigrinya
  #      :one => "",
  #      :other => ""
  #    },

  #    :tk => { # Turkmen
  #      :one => "",
  #      :other => ""
  #    },

  #    :tl => { # Tagalog
  #      :one => "",
  #      :other => ""
  #    },

  #    :to => { # Tonga (Tonga Islands)
  #      :other => ""
  #    },

      :tr => { # Turkish
        :other => "elma"
      },

      :uk => {
        :one => "яблуко",
        :few => "яблука",
        :many => "яблук",
        :other => "яблук"
      },

      :ur => { # Urdu
        :one => "سیب",
        :other => "سیب"
      },

      :vi => { # Vietnamese
        :other => "quả táo"
      },

  #    :wa => { # Walloon
  #      :one => "",
  #      :other => ""
  #    },
  #
  #    :yo => { # Yoruba
  #      :other => ""
  #    },

      :zh => { # Chinese
        :other => "个苹果"
      },

  #    :zu => { # Zulu
  #      :one => "",
  #      :other => ""
  #    }
    })
  end
end