require 'rails/generators'

module ExvoGlobalize

  # Creates a new migration adding the translations table to the application
  # and copies the exvo_globalize_i18n.js to public/javascripts/ (for Rails 3.0.x)
  #
  # @example
  # $ rails generate exvo_globalize:install
  class InstallGenerator < Rails::Generators::Base
    include Rails::Generators::Migration

    class_option :template_engine
    source_root File.join(File.dirname(__FILE__), 'templates')

    def self.next_migration_number(dirname)
      if ActiveRecord::Base.timestamped_migrations
        Time.now.utc.strftime("%Y%m%d%H%M%S")
      else
        "%.3d" % (current_migration_number(dirname) + 1)
      end
    end

    # Migrates template or skips if it already exists
    # see https://github.com/rails/rails/blob/master/railties/lib/rails/generators/migration.rb#L55
    def self.migrate_template_or_skip(source, destination)
      migration_dir = File.dirname(destination)

      migration_file_name = File.basename(destination).sub(/\.rb$/, '')
      unless migration_exists?(migration_dir, migration_file_name)
        migration_template(source, destination)
      end
    end

    desc "Add a 'create_globalize_translations' migration"
    def create_migration_file
      self.class.migrate_template_or_skip 'migration.rb', 'db/migrate/create_globalize_translations.rb'
      self.class.migrate_template_or_skip 'suggestions_migration.rb', 'db/migrate/create_globalize_translation_suggestions.rb'
    end

    if ::Rails::VERSION::MAJOR == 3 && ::Rails::VERSION::MINOR == 0
      desc "Copy the exvo_globalize_i18n.js to public/javascripts/"
      def copy_javascript_library
        template '../../../../app/assets/javascripts/exvo_globalize_i18n.js', 'public/javascripts/exvo_globalize_i18n.js'
      end
    end
  end
end